Crate yomo_derive

Crate yomo_derive 

YoMo Rust development sdk (macros)

This crate is designed for developers to implementing their own YoMo applications with Rust language.

Attribute Macros

handler
This is the streaming data process handler for your app. Therefore it will be executed once a data packet is incoming.
init
You can do the initialization tasks in this function.
observe_datatags
Return the observed datatags of this serverless function.